"""
Salt state module
"""
import logging

log = logging.getLogger(__name__)

__virtualname__ = "consul"


def __virtual__():
    # To force a module not to load return something like:
    #   return (False, "The consul state module is not implemented yet")

    # Replace this with your own logic
    if "consul.example_function" not in __salt__:
        return False, "The 'consul' execution module is not available"
    return __virtualname__


def exampled(name):
    """
    This example function should be replaced
    """
    ret = {"name": name, "changes": {}, "result": False, "comment": ""}
    value = __salt__["consul.example_function"](name)
    if value == name:
        ret["result"] = True
        ret["comment"] = f"The 'consul.example_function' returned: '{value}'"
    return ret



import pytest

pytestmark = [
    pytest.mark.requires_salt_modules("consul.example_function"),
]


@pytest.fixture
def consul(modules):
    return modules.consul


def test_replace_this_this_with_something_meaningful(consul):
    echo_str = "Echoed!"
    res = consul.example_function(echo_str)
    assert res == echo_str



"""
Salt execution module
"""
import logging

log = logging.getLogger(__name__)

__virtualname__ = "consul"


def __virtual__():
    # To force a module not to load return something like:
    #   return (False, "The consul execution module is not implemented yet")
    return __virtualname__


def example_function(text):
    """
    This example function should be replaced

    CLI Example:

    .. code-block:: bash

        salt '*' consul.example_function text="foo bar"
    """
    return __salt__["test.echo"](text)
